@@ -26,6 +26,7 @@ from ._algorithm_ import (
     ami,
     binary_indicator,
     z_score_to_p_value,
+    trs_scale_norm,
     random_walk,
     RandomWalk,
     euclidean_distances,
@@ -64,6 +65,7 @@ __all__ = [
     "ami",
     "binary_indicator",
     "z_score_to_p_value",
+    "trs_scale_norm",
     "random_walk",
     "RandomWalk",
     "euclidean_distances",
