@@ -621,7 +621,7 @@ def _random_walk_cpu_(
 
 class RandomWalkModel(nn.Module):
 
-    def __init__(self, weight: Union[matrix_data, Tensor], gamma: float = 0.05, epsilon: float = 1e-5, p: int = 2, device: str = 'auto', pbar=None):
+    def __init__(self, gamma: float = 0.05, epsilon: float = 1e-5, p: int = 2, device: str = 'auto', pbar=None):
         super().__init__()
         self.gamma = gamma
         self.epsilon = epsilon
@@ -632,11 +632,9 @@ class RandomWalkModel(nn.Module):
 
         self.device = 'cuda' if (device == 'gpu' or (device == 'auto' and is_gpu_available)) else 'cpu'
 
-        self.weight = torch.as_tensor(to_dense(weight, is_array=True), device=self.device, dtype=torch.float32) if isinstance(weight, matrix_data) else weight.to(self.device)
-
         self.factor = 1 - self.gamma
 
-    def core(self, seed_cell_vector: Tensor):
+    def core(self, seed_cell_vector: Tensor, weight: Tensor):
 
         p0 = seed_cell_vector
         pt = p0.clone()
@@ -645,7 +643,7 @@ class RandomWalkModel(nn.Module):
         k = 0
 
         while delta > self.epsilon:
-            p1 = self.factor * torch.matmul(self.weight, pt) + self.gamma * p0
+            p1 = self.factor * torch.matmul(weight, pt) + self.gamma * p0
             delta = torch.linalg.norm(pt - p1, ord=self.p).item()
             pt = p1
             k += 1
@@ -655,14 +653,14 @@ class RandomWalkModel(nn.Module):
 
         return pt.flatten()
 
-    def forward(self, seed_cell_weight: Tensor):
+    def forward(self, seed_cell_weight: Tensor, weight: Tensor):
 
         sample_count = seed_cell_weight.shape[1]
 
-        score = torch.zeros(seed_cell_weight.shape)
+        score = torch.zeros(seed_cell_weight.shape).cuda()
 
         for i in range(sample_count):
-            score[:, i] = self.core(seed_cell_weight[:, i])
+            score[:, i] = self.core(seed_cell_weight[:, i], weight)
 
         return score
 
@@ -678,20 +676,55 @@ def _random_walk_gpu_(
 
     with tqdm(total=seed_cell_weight.shape[1]) as pbar:
 
-        model = RandomWalkModel(weight, gamma, epsilon, p, device, pbar)
+        model = RandomWalkModel(gamma, epsilon, p, device, pbar)
 
         device = model.device
         model.to(device)
 
         seed_cell_weight = torch.as_tensor(seed_cell_weight, device=device, dtype=torch.float32)
+        weight = to_dense(weight, is_array=True)
+        weight = torch.as_tensor(weight, device=device, dtype=torch.float32)
 
-        if device == 'cuda' and torch.cuda.device_count() < seed_cell_weight.shape[1]:
-            model = nn.DataParallel(model, dim=1)
+        if device == 'cuda' and 1 < torch.cuda.device_count() < seed_cell_weight.shape[1]:
+
+            class CustomDataParallel(nn.DataParallel):
+
+                def scatter(self, inputs, kwargs, device_ids):
+                    _seed_cell_weight_, _weight_ = inputs
+                    scattered_seed_cell_weight = torch.nn.parallel.scatter(_seed_cell_weight_, device_ids, dim=1)
+                    scattered_weight = [_weight_.to(f'cuda:{device_id}') for device_id in device_ids]
+                    scattered_inputs = [(ssw, sw) for ssw, sw in zip(scattered_seed_cell_weight, scattered_weight)]
+
+                    scattered_kwargs = []
+
+                    for device_id in device_ids:
+                        device_kwargs = {}
+
+                        for key, value in kwargs.items():
+                            if isinstance(value, torch.Tensor):
+                                device_kwargs[key] = value.to(f'cuda:{device_id}')
+                            else:
+                                device_kwargs[key] = value
+
+                        scattered_kwargs.append(device_kwargs)
+
+                    return scattered_inputs, scattered_kwargs
+
+                def gather(self, outputs, output_device):
+                    """
+                    收集并行处理后的结果，检查是否存在结果，并将结果按列合并（每个结果矩阵，行数一样，列数不一样）
+                    :param outputs: 各个设备的输出结果
+                    :param output_device: 输出设备
+                    :return: 收集并按列合并后的结果
+                    """
+                    return torch.nn.parallel.scatter_gather.gather(outputs, output_device, dim=1)
+
+            model = CustomDataParallel(model)
 
         with torch.no_grad():
-            result = model(seed_cell_weight)
+            result = model(seed_cell_weight, weight)
 
-        return result.cpu().numpy().flatten()
+        return result.cpu().numpy()
 
 
 def random_walk(
@@ -717,9 +750,16 @@ def random_walk(
     elif device == 'gpu' or (device == 'auto' and availability):
         return _random_walk_gpu_(seed_cell_weight, weight, gamma, epsilon, p, device='gpu')
     else:
+        ul.log(__name__).error(f'The `device` ({device}) is not supported. Only supports "cpu", "gpu", and "auto" values.')
         raise ValueError(f'The `device` ({device}) is not supported. Only supports "cpu", "gpu", and "auto" values.')
 
 
+def trs_scale_norm(score: matrix_data, axis: Literal[0, 1, -1] = 0, is_verbose: bool = True) -> matrix_data:
+    cell_value = mean_symmetric_scale(score, axis=axis, is_verbose=is_verbose)
+    cell_value = np.log1p(min_max_norm(cell_value, axis=axis))
+    return cell_value
+
+
 class RandomWalk:
     """
     Random walk
@@ -815,7 +855,7 @@ class RandomWalk:
         self.benchmark_count = benchmark_count
         self._enrichment_seed_cell_min_count_ = 3
 
-        self.is_gpu_available = check_gpu_availability()
+        self.is_gpu_available = check_gpu_availability(False)
 
         if not is_simple and self.is_ablation:
             if "cell_mutual_knn" not in cc_adata.layers:
@@ -945,7 +985,7 @@ class RandomWalk:
         try:
             _data_ = random_walk(seed_cell_data, weight=w, gamma=gamma, epsilon=self.epsilon, p=self.p, device=device)
         except Exception as e:
-            ul.log(__name__).error(f"GPU failed to run, try to switch to CPU running.\n {e}")
+            ul.log(__name__).warning(f"GPU failed to run, try to switch to CPU running.\n {e}")
             _data_ = random_walk(seed_cell_data, weight=w, gamma=gamma, epsilon=self.epsilon, p=self.p, device='cpu')
 
         return _data_
@@ -1162,9 +1202,7 @@ class RandomWalk:
 
     @staticmethod
     def scale_norm(score: matrix_data, is_verbose: bool = False) -> matrix_data:
-        cell_value = mean_symmetric_scale(score, axis=0, is_verbose=is_verbose)
-        cell_value = np.log1p(min_max_norm(cell_value, axis=0))
-        return cell_value
+        return trs_scale_norm(score, axis=0, is_verbose=is_verbose)
 
     def _simple_error_(self) -> None:
 
